from setuptools import setup, find_packages
from distutils.core import setup
setup(
    name = 'zjy111',
    version = '1.0.0',
    py_modules = ['zjy111'],
    author = 'zjy_study',
    author_email = 'zjy_home@qq.com',
    url = 'https://test.pypi.org/legacy/',
    description = 'A simple printer of nested lists'    
    )
